# modo

A suite of tools for dealing with a directory of markdown files.

## Tasks

- TODO: improve inline help
- DONE: more flags
  - [x] filters
  - [x] sorting
  - [x] reverse sort
- TODO: add config file {by:2024-09-01}
  - [ ] make file types configurable
  - [ ] look in local dir, then XDG_HOME
- DONE: support checkboxes
  - [x] scan lists
  - [x] percent complete
- IDEA: recurring?
- IDEA: track changes
- IDEA: modify files
  - [ ] quick add
  - [ ] check box -> completion
  - [ ] finish (assigned temp tags?)
  - [ ] sort in file
        maybe requires a special section like ## Tasks
- DONE: decide on more permanent name {by:2024-08-15}
- DONE: add color {by: 2024-07-26}
- DONE: support multi-tags {like:this} {by: 2024-07-26}
